summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttMinimizeSplitter.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /kdgantt/KDGanttMinimizeSplitter.cpp
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kdgantt/KDGanttMinimizeSplitter.cpp')
-rw-r--r--kdgantt/KDGanttMinimizeSplitter.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdgantt/KDGanttMinimizeSplitter.cpp b/kdgantt/KDGanttMinimizeSplitter.cpp
index 09f0b8528..fb9eda893 100644
--- a/kdgantt/KDGanttMinimizeSplitter.cpp
+++ b/kdgantt/KDGanttMinimizeSplitter.cpp
@@ -108,7 +108,7 @@ void KDGanttSplitterHandle::mousePressEvent( TQMouseEvent *e )
_activeButton = onButton( e->pos() );
mouseOffset = s->pick(e->pos());
if ( _activeButton != 0)
- tqrepaint();
+ repaint();
updateCursor( e->pos() );
}
}
@@ -165,7 +165,7 @@ void KDGanttSplitterHandle::mouseReleaseEvent( TQMouseEvent *e )
s->moveSplitter( pos, id() );
}
}
- tqrepaint();
+ repaint();
}
int KDGanttSplitterHandle::onButton( const TQPoint& p )
@@ -319,7 +319,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
such a license) and are (C) Trolltech AS.
A splitter lets the user control the size of child widgets by
- dragging the boundary between the tqchildren. Any number of widgets
+ dragging the boundary between the children. Any number of widgets
may be controlled.
To show a TQListBox, a TQListView and a TQTextEdit side by side:
@@ -332,14 +332,14 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
\endcode
In KDGanttMinimizeSplitter, the boundary can be either horizontal or
- vertical. The default is horizontal (the tqchildren are side by side)
+ vertical. The default is horizontal (the children are side by side)
but you can use setOrientation( TQSplitter::Vertical ) to set it to
vertical.
Use setResizeMode() to specify
that a widget should keep its size when the splitter is resized.
- Although KDGanttMinimizeSplitter normally resizes the tqchildren only
+ Although KDGanttMinimizeSplitter normally resizes the children only
at the end of a resize operation, if you call setOpaqueResize( TRUE
) the widgets are resized as often as possible.
@@ -349,7 +349,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
sizes set by the user.
If you hide() a child, its space will be distributed among the other
- tqchildren. It will be reinstated when you show() it again. It is also
+ children. It will be reinstated when you show() it again. It is also
possible to reorder the widgets within the splitter using
moveToFirst() and moveToLast().
*/
@@ -400,7 +400,7 @@ KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( Qt::Orientation o, TQWidget *p
}
/*!
- Destroys the splitter and any tqchildren.
+ Destroys the splitter and any children.
*/
KDGanttMinimizeSplitter::~KDGanttMinimizeSplitter()
{
@@ -705,7 +705,7 @@ void KDGanttMinimizeSplitter::moveBefore( int pos, int id, bool upLeft )
} else {
int dd, newLeft, nextPos;
if( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
- dd = w->tqgeometry().right() - pos;
+ dd = w->geometry().right() - pos;
dd = TQMAX( pick(minSize(w)), TQMIN(dd, pick(w->maximumSize())));
newLeft = pos+1;
nextPos = newLeft + dd;
@@ -764,7 +764,7 @@ void KDGanttMinimizeSplitter::moveAfter( int pos, int id, bool upLeft )
newLeft = pos-dd+1;
nextPos = newLeft - 1;
} else {
- right = pick( w->tqgeometry().bottomRight() );
+ right = pick( w->geometry().bottomRight() );
dd = right - pos + 1;
dd = TQMAX( pick(minSize(w)), TQMIN(dd, pick(w->maximumSize())));
/*newRight = pos+dd-1;*/
@@ -966,7 +966,7 @@ void KDGanttMinimizeSplitter::recalc( bool update )
// nested splitters; be nice
maxl = maxt = 0;
} else {
// KDGanttMinimizeSplitter with no tqchildren yet
maxl = TQWIDGETSIZE_MAX;
}
} else {
@@ -966,7 +966,7 @@ void KDGanttMinimizeSplitter::recalc( bool update )
maxl = maxt = 0;
} else {
- // KDGanttMinimizeSplitter with no tqchildren yet
+ // KDGanttMinimizeSplitter with no children yet
maxl = TQWIDGETSIZE_MAX;
}